mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* sched: rename per cpu variable init_cfs_rq so that it does not share a common name with a function within the same scope.
@ 2009-08-29  5:40 Anirban Sinha
  2009-08-29 13:58 ` [tip:sched/core] sched: Rename init_cfs_rq => init_tg_cfs_rq tip-bot for Anirban Sinha
  0 siblings, 1 reply; 2+ messages in thread
From: Anirban Sinha @ 2009-08-29  5:40 UTC (permalink / raw)
  To: linux-kernel, Ingo Molnar

Resending the same patch since the previous patch might have had some
whitespace issues.

Ani


Signed-off-by: Anirban Sinha <asinha@zeugmasystems.com>
---
 kernel/sched.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/kernel/sched.c b/kernel/sched.c
index 1b59e26..e1e97b3 100644
--- a/kernel/sched.c
+++ b/kernel/sched.c
@@ -318,7 +318,7 @@ struct task_group root_task_group;
 /* Default task group's sched entity on each cpu */
 static DEFINE_PER_CPU(struct sched_entity, init_sched_entity);
 /* Default task group's cfs_rq on each cpu */
-static DEFINE_PER_CPU(struct cfs_rq, init_cfs_rq)
____cacheline_aligned_in_smp;
+static DEFINE_PER_CPU(struct cfs_rq, init_tg_cfs_rq)
____cacheline_aligned_in_smp;
 #endif /* CONFIG_FAIR_GROUP_SCHED */
 
 #ifdef CONFIG_RT_GROUP_SCHED
@@ -9304,11 +9304,11 @@ void __init sched_init(void)
 		 * system cpu resource, based on the weight assigned to
root
 		 * user's cpu share (INIT_TASK_GROUP_LOAD). This is
accomplished
 		 * by letting tasks of init_task_group sit in a separate
cfs_rq
-		 * (init_cfs_rq) and having one entity represent this
group of
+		 * (init_tg_cfs_rq) and having one entity represent this
group of
 		 * tasks in rq->cfs (i.e init_task_group->se[] != NULL).
 		 */
 		init_tg_cfs_entry(&init_task_group,
-				&per_cpu(init_cfs_rq, i),
+				&per_cpu(init_tg_cfs_rq, i),
 				&per_cpu(init_sched_entity, i), i, 1,
 				root_task_group.se[i]);
 
-- 
1.6.4


^ permalink raw reply	[flat|nested] 2+ messages in thread

* [tip:sched/core] sched: Rename init_cfs_rq => init_tg_cfs_rq
  2009-08-29  5:40 sched: rename per cpu variable init_cfs_rq so that it does not share a common name with a function within the same scope Anirban Sinha
@ 2009-08-29 13:58 ` tip-bot for Anirban Sinha
  0 siblings, 0 replies; 2+ messages in thread
From: tip-bot for Anirban Sinha @ 2009-08-29 13:58 UTC (permalink / raw)
  To: linux-tip-commits; +Cc: linux-kernel, hpa, mingo, asinha, ASinha, tglx, mingo

Commit-ID:  84e9dabf6e6a78928c6a1a8ba235c9fb0908d0f8
Gitweb:     http://git.kernel.org/tip/84e9dabf6e6a78928c6a1a8ba235c9fb0908d0f8
Author:     Anirban Sinha <ASinha@zeugmasystems.com>
AuthorDate: Fri, 28 Aug 2009 22:40:43 -0700
Committer:  Ingo Molnar <mingo@elte.hu>
CommitDate: Sat, 29 Aug 2009 15:51:16 +0200

sched: Rename init_cfs_rq => init_tg_cfs_rq

... so that it does not share a common name with a function
within the same scope.

Signed-off-by: Anirban Sinha <asinha@zeugmasystems.com>
LKML-Reference: <DDFD17CC94A9BD49A82147DDF7D545C501EA98A6@exchange.ZeugmaSystems.local>
Signed-off-by: Ingo Molnar <mingo@elte.hu>


---
 kernel/sched.c |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/kernel/sched.c b/kernel/sched.c
index 523e20a..6244d24 100644
--- a/kernel/sched.c
+++ b/kernel/sched.c
@@ -309,8 +309,8 @@ void set_tg_uid(struct user_struct *user)
 
 /*
  * Root task group.
- * 	Every UID task group (including init_task_group aka UID-0) will
- * 	be a child to this group.
+ *	Every UID task group (including init_task_group aka UID-0) will
+ *	be a child to this group.
  */
 struct task_group root_task_group;
 
@@ -318,7 +318,7 @@ struct task_group root_task_group;
 /* Default task group's sched entity on each cpu */
 static DEFINE_PER_CPU(struct sched_entity, init_sched_entity);
 /* Default task group's cfs_rq on each cpu */
-static DEFINE_PER_CPU(struct cfs_rq, init_cfs_rq) ____cacheline_aligned_in_smp;
+static DEFINE_PER_CPU(struct cfs_rq, init_tg_cfs_rq) ____cacheline_aligned_in_smp;
 #endif /* CONFIG_FAIR_GROUP_SCHED */
 
 #ifdef CONFIG_RT_GROUP_SCHED
@@ -9400,11 +9400,11 @@ void __init sched_init(void)
 		 * system cpu resource, based on the weight assigned to root
 		 * user's cpu share (INIT_TASK_GROUP_LOAD). This is accomplished
 		 * by letting tasks of init_task_group sit in a separate cfs_rq
 		 * (init_cfs_rq) and having one entity represent this group of
 		 * tasks in rq->cfs (i.e init_task_group->se[] != NULL).
 		 */
 		init_tg_cfs_entry(&init_task_group,
-				&per_cpu(init_cfs_rq, i),
+				&per_cpu(init_tg_cfs_rq, i),
 				&per_cpu(init_sched_entity, i), i, 1,
 				root_task_group.se[i]);
 

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2009-08-29 13:58 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -9400,11 +9400,11 @@ void __init sched_init(void)
 		 * user's cpu share (INIT_TASK_GROUP_LOAD). This is accomplished
 		 * by letting tasks of init_task_group sit in a separate cfs_rq
-		 * (init_cfs_rq) and having one entity represent this group of
+		 * (init_tg_cfs_rq) and having one entity represent this group of
 		 * tasks in rq->cfs (i.e init_task_group->se[] != NULL).
 		 */
2009-08-29  5:40 sched: rename per cpu variable init_cfs_rq so that it does not share a common name with a function within the same scope Anirban Sinha
2009-08-29 13:58 ` [tip:sched/core] sched: Rename init_cfs_rq => init_tg_cfs_rq tip-bot for Anirban Sinha

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®